@@ -2,11 +2,11 @@ qat_data_read_ncdf <-
 function(filename) {
 ## functionality: reads netcdf data
 ## author: André Düsterhus
-## date: 23.11.2009
-## version: A0.1
+## date: 30.10.2012
+## version: A0.2
 ## input: filename of an existing netcdf-file
 ## output: ncdf object
-	library("ncdf")
-	ncdfobj<-open.ncdf(filename)
+	library("ncdf4")
+	ncdfobj<-nc_open(filename)
 	return(ncdfobj)
 }
