@@ -2,11 +2,12 @@ qat_data_varcontent_ncdf <-
 function(obj,numofvar) {
 ## functionality: give back content of a variable
 ## author: André Düsterhus
-## date: 23.11.2009
-## version: A0.1
+## date: 30.10.2012
+## version: A0.2
 ## input: ncdf object, number of variable
 ## output: content of variable
+	library("ncdf4")
 	var<-obj$var[[numofvar]]
-	varcontent<-get.var.ncdf(obj,var)
+	varcontent<-ncvar_get(obj,var)
 	return(varcontent)
 }
