@@ -10,7 +10,7 @@ function(resultlist, filename, blocksize=-1, measurement_name="", directoryname=
 		# if no plotstyle available, use standard plotstyle
 		plotstyle<-qat_style_plot()
 	}
-	library(gplots)
+	library("gplots")
 	# set up savepath of the plot
 	path <- paste(directoryname,filename,"_1.png", sep="")
 	png(filename=path,width=800,height=600, pointsize=12, bg=plotstyle$basecolor)
